<?php

/* Reminder: always indent with 4 spaces (no tabs). */
// +---------------------------------------------------------------------------+
// | SocialShare Plugin 1.2                                                    |
// +---------------------------------------------------------------------------+
// | autoinstall.php                                                           |
// |                                                                           |
// | This file provides helper functions for the automatic plugin install.     |
// +---------------------------------------------------------------------------+
// | Copyright (C) 2009-2011 by the following authors:                         |
// |                                                                           |
// | Authors: Greg Gillis - greg DOT gillis AT sillig DOT com                  |
// +---------------------------------------------------------------------------+
// | Created with the Geeklog Plugin Toolkit.                                  |
// +---------------------------------------------------------------------------+
// |                                                                           |
// | This program is free software; you can redistribute it and/or             |
// | modify it under the terms of the GNU General Public License               |
// | as published by the Free Software Foundation; either version 2            |
// | of the License, or (at your option) any later version.                    |
// |                                                                           |
// | This program is distributed in the hope that it will be useful,           |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
// | GNU General Public License for more details.                              |
// |                                                                           |
// | You should have received a copy of the GNU General Public License         |
// | along with this program; if not, write to the Free Software Foundation,   |
// | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
// |                                                                           |
// +---------------------------------------------------------------------------+

/**
* @package SocialShare
*/

/**
* Plugin autoinstall function
*
* @param    string  $pi_name    Plugin name
* @return   array               Plugin information
*
*/
function plugin_autoinstall_socialshare($pi_name)
{
    $pi_name         = 'socialshare';
    $pi_display_name = 'SocialShare';
    $pi_admin        = $pi_display_name . ' Admin';

    $info = array(
        'pi_name'         => $pi_name,
        'pi_display_name' => $pi_display_name,
        'pi_version'      => '1.2',
        'pi_gl_version'   => '1.6+',
        'pi_homepage'     => 'http://www.sillig.com'
    );

    $groups = array(
        $pi_admin => 'Users in this group can administer the '
                     . $pi_display_name . ' plugin'
    );

    $features = array(
        $pi_name . '.admin'    => 'Full access to ' . $pi_display_name
                                  . ' plugin'
    );

    $mappings = array(
        $pi_name . '.admin'     => array($pi_admin)
    );

    $tables = array(
        'socialshare'
    );

    $inst_parms = array(
        'info'      => $info,
        'groups'    => $groups,
        'features'  => $features,
        'mappings'  => $mappings,
        'tables'    => $tables
    );

    return $inst_parms;
}



/**
* Plugin postinstall
*
* We're inserting our default data here since it depends on other stuff that
* has to happen first ...
*
* @return   boolean     true = proceed with install, false = an error occured
*
*/
function plugin_postinstall_socialshare($pi_name)
{
    global $_CONF, $_TABLES;

    require_once $_CONF['path_system'] . 'classes/config.class.php';

    $socialshare_config = config::get_instance();
    $_SOCIALSHARE_CONF = $socialshare_config->get_config('socialshare');

    $inst_parms = plugin_autoinstall_socialshare($pi_name);
    $pi_admin = key($inst_parms['groups']);

    $admin_group_id = DB_getItem($_TABLES['groups'], 'grp_id',
                                 "grp_name = '{$pi_admin}'");
    $blockadmin_id = DB_getItem($_TABLES['groups'], 'grp_id',
                                "grp_name = 'Block Admin'");

    $L_SQL = array();

    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (1, 290, 'http://digg.com/submit?phase=2&url=<SHAREURL>&title=<SHARETITLE>\r\n', 'Digg', 'digg.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (32, 220, 'http://www.wikio.com/vote?url=<SHAREURL>', 'Wikio', 'wikio.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (2, 370, 'http://del.icio.us/post?url=<SHAREURL>&title=<SHARETITLE>', 'Del.icio.us', 'delicious.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (3, 10, 'http://www.facebook.com/share.php?u=<SHAREURL>&t=<SHARETITLE>', 'Facebook', 'facebook.png', 1, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (4, 140, 'http://www.mixx.com/submit?page_url=<SHAREURL>&title=<SHARETITLE>', 'Mixx', 'mixx.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (5, 360, 'http://cgi.fark.com/cgi/fark/farkit.pl?h=<SHARETITLE>&u=<SHAREURL>', 'Fark', 'fark.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (7, 350, 'http://www.myspace.com/Modules/PostTo/Pages/?u=<SHAREURL>&t=<SHARETITLE>', 'MySpace', 'myspace.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (9, 430, 'http://buzz.yahoo.com/submit/?submitUrl=<SHAREURL>&submitHeadline=<SHARETITLE>&submitSummary=<SHARETEXT>&submitCategory=science&submitAssetType=text', 'Yahoo Buzz', 'yahoobuzz.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (11, 340, 'http://reddit.com/submit?url=<SHAREURL>&title=<SHARETITLE>', 'Reddit', 'reddit.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (12, 330, 'http://slashdot.org/bookmark.pl?title=<SHARETITLE>&url=<SHAREURL>', 'SlashDot', 'slashdot.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (13, 320, 'http://www.sphere.com/search?q=sphereit:<SHAREURL>&title=<SHARETITLE>', 'Sphere', 'sphere.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (14, 20, 'http://www.google.com/bookmarks/mark?op=edit&bkmk=<SHAREURL>&title=<SHARETITLE>&annotation=<SHARETEXT>', 'Google Bookmarks', 'googlebookmark.png', 1, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (15, 310, 'http://twitter.com/home?status=<SHAREURL>', 'Twitter', 'twitter.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (16, 400, 'http://blogmarks.net/my/new.php?mini=1&simple=1&url=<SHAREURL>&title=<SHARETITLE>', 'Blogmarks', 'blogmarks.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (17, 300, 'http://internetmedia.hu/submit.php?url=<SHAREURL>', 'IM', 'im.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (18, 240, 'http://linkarena.com/bookmarks/addlink/?url=<SHAREURL>&title=<SHARETITLE>', 'Link Areana', 'linkarena.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (19, 250, 'http://www.gwar.pl/DodajGwar.html?u=<SHAREURL>', 'GWar', 'gwar.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (20, 260, 'http://globalgrind.com/submission/submit.aspx?url=<SHAREURL>&type=Article&title=<SHARETITLE>', 'Global Grind', 'globalgrind.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (21, 270, 'http://www.dzone.com/links/add.html?url=<SHAREURL>&title=<SHARETITLE>', 'Dzone', 'dzone.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (31, 230, 'http://www.xerpi.com/block/add_link_from_extension?url=<SHAREURL>&title=<SHARETITLE>', 'Xerpi', 'xerpi.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (25, 280, 'http://nujij.nl/jij.lynkx?t=<SHARETITLE>&u=<SHAREURL>', 'NuJIJ', 'nujij.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (34, 200, 'http://socialogs.com/add_story.php?story_url=<SHAREURL>&story_title=<SHARETITLE>', 'Socialogs', 'socialogs.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (33, 210, 'http://www.upnews.it/submit?url=<SHAREURL>&title=<SHARETITLE>', 'Upnews', 'upnews.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (27, 420, 'http://www.blinklist.com/index.php?Action=Blink/addblink.php&Url=<SHAREURL>&Title=<SHARETITLE>', 'BlinkList', 'blinklist.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (28, 410, 'http://www.blogmemes.net/post.php?url=<SHAREURL>&title=<SHARETITLE>', 'BlogMemes', 'blogmemes.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (29, 390, 'http://cimlap.blogter.hu/index.php?action=suggest_link&title=<SHARETITLE>&url=<SHAREURL>', 'Blogter', 'blogter.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (30, 380, 'http://co.mments.com/track?url=<SHAREURL>&title=<SHARETITLE>', 'Co.mments', 'co.mments.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (35, 190, 'http://ratimarks.org/bookmarks.php/?action=add&address=<SHAREURL>&title=<SHARETITLE>', 'Ratimarks', 'ratimarks.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (36, 180, 'http://www.propeller.com/submit/?url=<SHAREURL>', 'Propeller', 'propeller.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (38, 160, 'http://www.n4g.com/tips.aspx?url=<SHAREURL>&title=<SHARETITLE>', 'N4G', 'n4g.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (39, 150, 'http://www.muti.co.za/submit?url=<SHAREURL>&title=<SHARETITLE>', 'muti', 'muti.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (40, 130, 'http://meneame.net/submit.php?url=<SHAREURL>', 'Meneame', 'meneame.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (41, 120, 'http://www.linkedin.com/shareArticle?mini=true&url=<SHAREURL>&title=<SHARETITLE>&summary=<SHARETEXT>', 'LinkedIn', 'linkedin.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (42, 110, 'http://laaik.it/NewStoryCompact.aspx?uri=<SHAREURL>&headline=<SHARETITLE>', 'Laaik.it', 'laaikit.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (43, 100, 'http://www.kirtsy.com/submit.php?url=<SHAREURL>&title=<SHARETITLE>', 'Kirtsy', 'kirtsy.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (47, 90, 'http://mystuff.ask.com/mysearch/QuickWebSave?v=1.2&t=webpages&title=<SHARETITLE>&url=<SHAREURL>', 'Ask', 'ask.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (48, 80, 'http://www.blinkbits.com/bookmarklets/save.php?v=1&source_url=<SHAREURL>&title=<SHARETITLE>&body=<SHARETEXT>', 'Blinkbits', 'blinkbits.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (49, 70, 'http://www.bloglines.com/sub/<SHAREURL>', 'Bloglines', 'bloglines.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (50, 60, 'http://cimlap.blogter.hu/index.php?action=suggest_link&title=<SHARETITLE>&url=<SHAREURL>', 'Blogter AC', 'blogtercimlap.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (51, 50, 'http://www.bumpzee.com/bump.php?u=<SHAREURL>', 'Bumpzee', 'bumpzee.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (52, 40, 'http://www.connotea.org/addpopup?continue=confirm&uri=<SHAREURL>&title=<SHARETITLE>', 'Connotea', 'connotea.png', 0, 4)";
    $L_SQL[] = "INSERT INTO {$_TABLES['socialshare']}  VALUES  (53, 30, 'http://www.dotnetkicks.com/kick/?url<SHAREURL>&title=<SHARETITLE>', 'Dotnetkicks', 'dotnetkicks.png', 0, 4);";
	
	
	
	
    foreach ($L_SQL as $sql) {
        $sql = str_replace('#group#', $admin_group_id, $sql);
        DB_query($sql, 1);
        if (DB_error()) {
            COM_error("SQL error in SocialShare plugin postinstall, SQL: " . $sql);
            return false;
        }
    }

    return true;
}





/**
* Check if the plugin is compatible with this Geeklog version
*
* @param    string  $pi_name    Plugin name
* @return   boolean             true: plugin compatible; false: not compatible
*
*/
function plugin_compatible_with_this_version_socialshare($pi_name)
{
    global $_CONF, $_DB_dbms;

    // check if we support the DBMS the site is running on
    $dbFile = $_CONF['path'] . 'plugins/' . $pi_name . '/sql/'
            . $_DB_dbms . '_install.php';
    if (! file_exists($dbFile)) {
        return false;
    }

    // add checks here

    return true;
}

?>
